window.Gleam.initSearch([{"doc":"adglent","title":"adglent","content":"# adglent\n\n[![Package Version](https://img.shields.io/hexpm/v/adglent)](https://hex.pm/packages/adglent)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/adglent/)\n\n## About\n\n`adglent` is a Gleam library which can be used to setup testing code and a template for implementing solution to [Advent of code](https://adventofcode.com/) problems.\n\n&gt; NOTE: `adglent` **only** supports `erlang` target (default) for Gleam.\n\n## Prerequisites\n\n`adglent` is written in `gleam` and runs and tests solutions written in Gleam. Read more about `gleam` at [gleam.run](https://gleam.run).\n\nThe easiest way to install `gleam` is to use `asdf`:\n\n1. Install `asdf` according to the instructions at the [asdf website](https://asdf-vm.com/)\n2. Install the gleam asdf plugin: `asdf plugin-add gleam`\n3. Install the latest `asdf install gleam latest`\n4. Use the latest gleam version globally: `asdf global gleam latest`\n\n&gt; HINT: `asdf` can manage multiple versions of gleam and the version can be set globally and also locally (`asdf local gleam &lt;VERSION&gt;`) to use a specific gleam version in a project.\n\n## Installation\n\nStart a new gleam project for your AOC soluctions with `gleam new`. In the project folder run:\n\n```sh\ngleam add --dev adglent\n```\n\n## Usage\n\n### Initializing\n\nFirst log in to [Advent of code](https://adventofcode.com/) and copy your personal `session-cookie`. The value can be found using developer tools in the browser (in Chrome: &quot;Application-&gt;Cookies-&gt;https://adventofcode.com-&gt;session&quot; and copy the Cookie-value)\n\n```sh\ngleam run -m adglent/init\n```\n\nInput the AOC year, you personal AOC session cookie and select if `showtime` should be used for tests (otherwise it will assume the project uses `gleeunit` as is default for `gleam new &lt;project&gt;`)\n\n&gt; NOTE: `showtime` is an alternate gleam test-runner. It is still quite new and havn&#39;t been tested in as many project as `gleeunit`. It has a different way of formatting the test-results and also supports the possibility to run specific test-modules (which can be useful in AOC). `showtime` is a standalone project but have been embedded into `adglent`.\n\n### Add day\n\nTo start working on the solution for a specific day run:\n\n```sh\ngleam run -m adglent/day &lt;NUM&gt;\n```\n\nWhere `&lt;NUM&gt;` is the day number of the day you want to solve a problem for.\n\n&gt; Example (start solving 1st of December):\n&gt;\n&gt; ```sh\n&gt; gleam run -m adglent/day 1\n&gt; ```\n\nAdding a day will add tests in `test/day&lt;NUM&gt;/day&lt;NUM&gt;_test.gleam`and a `src/day&lt;NUM&gt;/solve.gleam` file where the solution can be implemented.\n\nFurthermore it will also download the input for the problem to `src/day&lt;NUM&gt;/input.txt`\n\nBefore running the tests you need to provide one or more example. These can be found in the problem description for that day at the AOC website.\n\nAdd an example to a part of the problem by adding examples to the `part1_examples` or `part2_examples` lists.\n\n&gt; Example (input &quot;Hello Joe!&quot; should give answer 613411):\n&gt;\n&gt; ```gleam\n&gt; const part1_examples: List(Example(Problem1AnswerType)) = [\n&gt;   Example(&quot;Hello Joe!&quot;, &quot;613411&quot;),\n&gt; ]\n&gt; ```\n\nThe type of the answer for a part can be adjusted if needed by changing the type aliases `Problem1AnswerType` / `Problem2AnswerType`. Note that this will change the type that the `part1` / `part2` functions in `solve.gleam` expect to return.\n\n### Testing\n\nTo test all days in the project use:\n\n```sh\ngleam test\n```\n\nIf you are using `showtime` you can test a single day by running:\n\n```sh\ngleam test -- --modules=day&lt;NUM&gt;/day&lt;NUM&gt;_test\n```\n\n&gt; Example (test solution for 1st of December):\n&gt;\n&gt; ```sh\n&gt; gleam test -- --modules=day1/day1_test\n&gt; ```\n\n### Get the answer\n\nTo get the (hopefully correct) answer after the tests are ok run:\n\n```sh\ngleam run -m day&lt;NUM&gt;/solve &lt;PART&gt;\n```\n\nwhere `&lt;NUM&gt;` is the day to solve and `&lt;PART&gt;` is the part of the problem (1 or 2) to solve.\n\nThis will run the solver and print the answer to stdout.\n\n### Module documentation\n\nModule documentation can be found at &lt;https://hexdocs.pm/adglent&gt;.\n","url":"index.html"},{"doc":"adglent","title":"Example","content":"pub type Example(a) {\n  Example(input: String, answer: a)\n}\n\nExample(input: String, answer: a)\n\n\nSynonyms:\nadglent.Example\nadglent Example","url":"adglent.html#Example"},{"doc":"adglent","title":"Problem","content":"pub type Problem {\n  First\n  Second\n}\n\nFirst\n\n\nSecond\n\n\nSynonyms:\nadglent.Problem\nadglent Problem","url":"adglent.html#Problem"},{"doc":"adglent","title":"get_input","content":"pub fn get_input(day: String) -&gt; Result(String, FileError)\n\nSynonyms:\nadglent.get_input\nadglent get_input","url":"adglent.html#get_input"},{"doc":"adglent","title":"get_part","content":"pub fn get_part() -&gt; Result(Problem, Nil)\n\nSynonyms:\nadglent.get_part\nadglent get_part","url":"adglent.html#get_part"},{"doc":"adglent","title":"get_test_folder","content":"pub fn get_test_folder(day: String) -&gt; String\n\nSynonyms:\nadglent.get_test_folder\nadglent get_test_folder","url":"adglent.html#get_test_folder"},{"doc":"adglent","title":"inspect","content":"pub fn inspect(value: a) -&gt; String\n\nSynonyms:\nadglent.inspect\nadglent inspect","url":"adglent.html#inspect"},{"doc":"adglent","title":"start_arguments","content":"pub fn start_arguments() -&gt; List(String)\n\nSynonyms:\nadglent.start_arguments\nadglent start_arguments","url":"adglent.html#start_arguments"},{"doc":"adglent","title":"adglent","content":"","url":"adglent.html"},{"doc":"priv/aoc_client","title":"get_input","content":"pub fn get_input(\n  year: String,\n  day: String,\n  session: String,\n) -&gt; Result(String, String)\n\nSynonyms:\npriv/aoc_client.get_input\npriv/aoc_client get_input","url":"priv/aoc_client.html#get_input"},{"doc":"priv/aoc_client","title":"priv/aoc_client","content":"","url":"priv/aoc_client.html"},{"doc":"priv/errors","title":"assert_ok","content":"pub fn assert_ok(result: Result(a, String)) -&gt; a\n\nSynonyms:\npriv/errors.assert_ok\npriv/errors assert_ok","url":"priv/errors.html#assert_ok"},{"doc":"priv/errors","title":"map_error","content":"pub fn map_error(\n  result: Result(a, b),\n  error_message: String,\n) -&gt; Result(a, String)\n\nSynonyms:\npriv/errors.map_error\npriv/errors map_error","url":"priv/errors.html#map_error"},{"doc":"priv/errors","title":"map_messages","content":"pub fn map_messages(\n  result: Result(a, b),\n  success_message: String,\n  error_message: String,\n) -&gt; Result(String, String)\n\nSynonyms:\npriv/errors.map_messages\npriv/errors map_messages","url":"priv/errors.html#map_messages"},{"doc":"priv/errors","title":"print_error","content":"pub fn print_error(\n  result: Result(a, String),\n) -&gt; Result(a, String)\n\nSynonyms:\npriv/errors.print_error\npriv/errors print_error","url":"priv/errors.html#print_error"},{"doc":"priv/errors","title":"print_result","content":"pub fn print_result(\n  result: Result(String, String),\n) -&gt; Result(String, String)\n\nSynonyms:\npriv/errors.print_result\npriv/errors print_result","url":"priv/errors.html#print_result"},{"doc":"priv/errors","title":"priv/errors","content":"","url":"priv/errors.html"},{"doc":"priv/template","title":"render","content":"pub fn render(\n  template: String,\n  substitutions: List(#(String, String)),\n) -&gt; String\n\nSynonyms:\npriv/template.render\npriv/template render","url":"priv/template.html#render"},{"doc":"priv/template","title":"priv/template","content":"","url":"priv/template.html"},{"doc":"priv/templates/solution","title":"template","content":"pub const template: String\n\nSynonyms:\npriv/templates/solution.template\npriv/templates/solution template","url":"priv/templates/solution.html#template"},{"doc":"priv/templates/solution","title":"priv/templates/solution","content":"","url":"priv/templates/solution.html"},{"doc":"priv/templates/testfile_gleeunit","title":"template","content":"pub const template: String\n\nSynonyms:\npriv/templates/testfile_gleeunit.template\npriv/templates/testfile_gleeunit template","url":"priv/templates/testfile_gleeunit.html#template"},{"doc":"priv/templates/testfile_gleeunit","title":"priv/templates/testfile_gleeunit","content":"","url":"priv/templates/testfile_gleeunit.html"},{"doc":"priv/templates/testfile_showtime","title":"template","content":"pub const template: String\n\nSynonyms:\npriv/templates/testfile_showtime.template\npriv/templates/testfile_showtime template","url":"priv/templates/testfile_showtime.html#template"},{"doc":"priv/templates/testfile_showtime","title":"priv/templates/testfile_showtime","content":"","url":"priv/templates/testfile_showtime.html"},{"doc":"priv/toml","title":"TomError","content":"pub type TomError {\n  TomParseError(error: tom.ParseError)\n  TomGetError(error: tom.GetError)\n}\n\nTomParseError(error: tom.ParseError)\n\n\nTomGetError(error: tom.GetError)\n\n\nSynonyms:\npriv/toml.TomError\npriv/toml TomError","url":"priv/toml.html#TomError"},{"doc":"priv/toml","title":"get_bool","content":"pub fn get_bool(\n  toml_content: String,\n  key_path: List(String),\n) -&gt; Result(Bool, TomError)\n\nSynonyms:\npriv/toml.get_bool\npriv/toml get_bool","url":"priv/toml.html#get_bool"},{"doc":"priv/toml","title":"get_int","content":"pub fn get_int(\n  toml_content: String,\n  key_path: List(String),\n) -&gt; Result(Int, TomError)\n\nSynonyms:\npriv/toml.get_int\npriv/toml get_int","url":"priv/toml.html#get_int"},{"doc":"priv/toml","title":"get_string","content":"pub fn get_string(\n  toml_content: String,\n  key_path: List(String),\n) -&gt; Result(String, TomError)\n\nSynonyms:\npriv/toml.get_string\npriv/toml get_string","url":"priv/toml.html#get_string"},{"doc":"priv/toml","title":"priv/toml","content":"","url":"priv/toml.html"},{"doc":"adglent/day","title":"main","content":"pub fn main() -&gt; String\n\nSynonyms:\nadglent/day.main\nadglent/day main","url":"adglent/day.html#main"},{"doc":"adglent/day","title":"adglent/day","content":"","url":"adglent/day.html"},{"doc":"priv/prompt","title":"GetLineError","content":"pub type GetLineError {\n  Eof\n  NoData\n}\n\nEof\n\n\nNoData\n\n\nSynonyms:\npriv/prompt.GetLineError\npriv/prompt GetLineError","url":"priv/prompt.html#GetLineError"},{"doc":"priv/prompt","title":"confirm","content":"pub fn confirm(message: String, auto_accept: Bool) -&gt; Bool\n\nSynonyms:\npriv/prompt.confirm\npriv/prompt confirm","url":"priv/prompt.html#confirm"},{"doc":"priv/prompt","title":"get_line","content":"pub fn get_line(\n  prompt prompt: String,\n) -&gt; Result(String, GetLineError)\n\nSynonyms:\npriv/prompt.get_line\npriv/prompt get_line","url":"priv/prompt.html#get_line"},{"doc":"priv/prompt","title":"value","content":"pub fn value(\n  message: String,\n  default: String,\n  auto_accept: Bool,\n) -&gt; String\n\nSynonyms:\npriv/prompt.value\npriv/prompt value","url":"priv/prompt.html#value"},{"doc":"priv/prompt","title":"priv/prompt","content":"","url":"priv/prompt.html"},{"doc":"priv/templates/test_main","title":"template","content":"pub const template: String\n\nSynonyms:\npriv/templates/test_main.template\npriv/templates/test_main template","url":"priv/templates/test_main.html#template"},{"doc":"priv/templates/test_main","title":"priv/templates/test_main","content":"","url":"priv/templates/test_main.html"},{"doc":"adglent/init","title":"main","content":"pub fn main() -&gt; Result(String, String)\n\nSynonyms:\nadglent/init.main\nadglent/init main","url":"adglent/init.html#main"},{"doc":"adglent/init","title":"adglent/init","content":"","url":"adglent/init.html"}]);